package org.eclipse.nebula.widgets.xviewer.customize.dialog;

import org.eclipse.swt.widgets.*;
import org.eclipse.swt.*;
import org.eclipse.swt.events.*;
import org.eclipse.swt.layout.*;
import org.eclipse.nebula.widgets.xviewer.customize.*;
import org.eclipse.nebula.widgets.xviewer.util.internal.*;
import org.eclipse.nebula.widgets.xviewer.*;

/**
 * Customization dialog UI section for configuring the table filter.
 *
 * @author Chris Merrill
 */
public class FilterCustomUISection implements CustomizeDialogUISection {
   @Override
   public Control createSection(Composite parent) {
      Composite body = new Composite(parent, SWT.NONE);
      final GridLayout layout = new GridLayout();
      layout.numColumns = 3;
      body.setLayout(layout);
      body.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false));

      final Label filterLabel = new Label(body, SWT.NONE);
      filterLabel.setText("Filter Text:");

      filterText = new Text(body, SWT.BORDER);
      filterText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));

      final Label clearFilterLabel = new Label(body, SWT.PUSH);
      clearFilterLabel.setImage(XViewerLib.getImage("clear.gif"));
      clearFilterLabel.addMouseListener(new MouseListener() {
         @Override
         public void mouseDown(MouseEvent e) {
            // do nothing
         }

         @Override
         public void mouseDoubleClick(MouseEvent e) {
            // do nothing

         }

         @Override
         public void mouseUp(MouseEvent e) {
            filterText.setText("");
         }
      });
      return body;
   }

   @Override
   public String getName() {
      return "Filter";
   }

   @Override
   public void readFromCustomData(CustomizeData customData) {
      filterText.setText(customData.getFilterData().getFilterText());
   }

   @Override
   public void saveToCustomData(CustomizeData customData) {
      customData.getFilterData().setFilterText(filterText.getText());
   }

   @Override
   public void columnVisibilityChanged(java.util.List<XViewerColumn> visible, java.util.List<XViewerColumn> hidden) {
      // nothing column-specific in this section
   }

   private Text filterText;
}


